@@ -26,8 +26,8 @@
 #endif
 
 #include "myparser.h"
+#include <cstdlib>
 #include <iostream>
-#include <stdlib.h>
 
 int main(int /* argc */, char** /* argv */)
 {
