@@ -34,14 +34,14 @@ protected:
   //overrides:
   void on_start_document() override;
   void on_end_document() override;
-  void on_start_element(const Glib::ustring& name,
+  void on_start_element(const xmlpp::ustring& name,
                                 const AttributeList& properties) override;
-  void on_end_element(const Glib::ustring& name) override;
-  void on_characters(const Glib::ustring& characters) override;
-  void on_comment(const Glib::ustring& text) override;
-  void on_warning(const Glib::ustring& text) override;
-  void on_error(const Glib::ustring& text) override;
-  void on_fatal_error(const Glib::ustring& text) override;
+  void on_end_element(const xmlpp::ustring& name) override;
+  void on_characters(const xmlpp::ustring& characters) override;
+  void on_comment(const xmlpp::ustring& text) override;
+  void on_warning(const xmlpp::ustring& text) override;
+  void on_error(const xmlpp::ustring& text) override;
+  void on_fatal_error(const xmlpp::ustring& text) override;
 };
 
 
